#!/bin/bash

#     Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
#     The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
# 
#     THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# 
#    Copyright (c) 2012-2013 by Deon George

# Check our arguments
while getopts ":DF:k:P:t:" opt; do
	case $opt in
		D) DEBUG=1 ;;

		# Filespace to store in TSM
		F) FILESPACE=$OPTARG ;;

		# Kerberos options
		k) KERBEROS_ARGS=$OPTARG ;;

		# PITDATE to restore
		P) PITDATE=$OPTARG ;;

		# Alternative TMP dir
		t) TMPDIR=$OPTARG ;;

		# Error Checking
		\?)
			echo "Invalid option: -$OPTARG" >&2
			exit 1
			;;
		:)
			echo "Option -$OPTARG requires an argument." >&2
			exit 1
			;;
	esac
done

# Our defaults
TMPDIR=${TMPDIR:-"/tmp"}

FILESPACE=${FILESPACE:-"/kerberos"}

# TSMPIPE ARGUMENTS
[ -n "$PITDATE" ] && TSMPIPE_ARGS="${TSMPIPE_ARGS} -P ${PITDATE}"

[ -n "$DEBUG" ] && echo "Processing Kerberos"

# Restore from TSM
tsmpipe -Bxs ${FILESPACE} -f FULL ${TSMPIPE_ARGS} > ${TMPDIR}/kerberos.$$.dump && kdb5_util ${KERBEROS_ARGS} load ${TMPDIR}/kerberos.$$.dump
rm -f ${TMPDIR}/kerberos.$$.dump
